@@ -1,5 +1,5 @@
 #-----------------------------------------------------------------------------
-# Copyright (c) 2012 - 2020, Anaconda, Inc., and Bokeh Contributors.
+# Copyright (c) 2012 - 2021, Anaconda, Inc., and Bokeh Contributors.
 # All rights reserved.
 #
 # The full license is in the file LICENSE.txt, distributed with this software.
@@ -11,6 +11,8 @@
 #-----------------------------------------------------------------------------
 # Boilerplate
 #-----------------------------------------------------------------------------
+from __future__ import annotations
+
 import logging # isort:skip
 log = logging.getLogger(__name__)
 
@@ -21,7 +23,7 @@ log = logging.getLogger(__name__)
 # Standard library imports
 import webbrowser
 from os.path import abspath
-from typing import Optional, cast
+from typing import Dict, cast
 
 # External imports
 from typing_extensions import Literal, Protocol
@@ -33,7 +35,10 @@ from ..settings import settings
 # Globals and constants
 #-----------------------------------------------------------------------------
 
-NEW_PARAM = {'tab': 2, 'window': 1}
+BrowserTarget = Literal["same", "window", "tab"]
+TargetCode = Literal[0, 1, 2]
+
+NEW_PARAM: Dict[BrowserTarget, TargetCode] = {"same": 0, "window": 1, "tab": 2}
 
 __all__ = (
     'DummyWebBrowser',
@@ -49,28 +54,28 @@ class BrowserLike(Protocol):
     ''' Interface for browser-like objects.
 
     '''
-    def open(self, url: str, new: int = 0, autoraise: bool = True) -> bool:
+    def open(self, url: str, new: TargetCode = ..., autoraise: bool = ...) -> bool:
         ...
 
-class DummyWebBrowser(object):
+class DummyWebBrowser:
     ''' A "no-op" web-browser controller.
 
     '''
-    def open(self, url: str, new: int = 0, autoraise: bool = True) -> bool:
+    def open(self, url: str, new: TargetCode = 0, autoraise: bool = True) -> bool:
         ''' Receive standard arguments and take no action. '''
         return True
 
-def get_browser_controller(browser: Optional[str] = None) -> BrowserLike:
+def get_browser_controller(browser: str | None = None) -> BrowserLike:
     ''' Return a browser controller.
 
     Args:
         browser (str or None) : browser name, or ``None`` (default: ``None``)
             If passed the string ``'none'``, a dummy web browser controller
-            is returned
+            is returned.
 
             Otherwise, use the value to select an appropriate controller using
-            the ``webbrowser`` standard library module. In the value is
-            ``None`` then a system default is used.
+            the :doc:`webbrowser <python:library/webbrowser>` standard library
+            module. If the value is ``None``, a system default is used.
 
     Returns:
         controller : a web browser controller
@@ -87,7 +92,7 @@ def get_browser_controller(browser: Optional[str] = None) -> BrowserLike:
 
     return controller
 
-def view(location: str, browser: Optional[str] = None, new: Literal["same", "window", "tab"] = "same", autoraise: bool = True) -> None:
+def view(location: str, browser: str | None = None, new: BrowserTarget = "same", autoraise: bool = True) -> None:
     ''' Open a browser to view the specified location.
 
     Args:
@@ -111,9 +116,9 @@ def view(location: str, browser: Optional[str] = None, new: Literal["same", "win
 
     '''
     try:
-        new_id = {"same": 0, "window": 1, "tab": 2}[new]
+        new_id = NEW_PARAM[new]
     except KeyError:
-        raise RuntimeError("invalid 'new' value passed to view: %r, valid values are: 'same', 'window', or 'tab'" % new)
+        raise RuntimeError(f"invalid 'new' value passed to view: {new!r}, valid values are: 'same', 'window', or 'tab'")
 
     if location.startswith("http"):
         url = location
