@@ -8,6 +8,8 @@
 #-----------------------------------------------------------------------------
 # Boilerplate
 #-----------------------------------------------------------------------------
+from __future__ import annotations # isort:skip
+
 import pytest ; pytest
 
 #-----------------------------------------------------------------------------
@@ -18,7 +20,12 @@ import pytest ; pytest
 import itertools
 
 # Bokeh imports
-from bokeh.models import ColumnDataSource, GlyphRenderer, Legend, LegendItem
+from bokeh.models import (
+    ColumnDataSource,
+    GlyphRenderer,
+    Legend,
+    LegendItem,
+)
 
 # Module under test
 import bokeh.plotting._legends as bpl # isort:skip
