@@ -1,5 +1,5 @@
 #-----------------------------------------------------------------------------
-# Copyright (c) 2012 - 2020, Anaconda, Inc., and Bokeh Contributors.
+# Copyright (c) 2012 - 2021, Anaconda, Inc., and Bokeh Contributors.
 # All rights reserved.
 #
 # The full license is in the file LICENSE.txt, distributed with this software.
@@ -8,6 +8,8 @@
 #-----------------------------------------------------------------------------
 # Boilerplate
 #-----------------------------------------------------------------------------
+from __future__ import annotations # isort:skip
+
 import pytest ; pytest
 
 #-----------------------------------------------------------------------------
@@ -40,7 +42,7 @@ def test_data() -> None:
     assert isinstance(bsl.data, dict)
 
     # check detail for package data
-    assert set(bsl.data.keys()) == set(['links', 'nodes'])
+    assert set(bsl.data.keys()) == {"links", "nodes"}
 
 
 #-----------------------------------------------------------------------------
