@@ -1,5 +1,5 @@
 #-----------------------------------------------------------------------------
-# Copyright (c) 2012 - 2020, Anaconda, Inc., and Bokeh Contributors.
+# Copyright (c) 2012 - 2021, Anaconda, Inc., and Bokeh Contributors.
 # All rights reserved.
 #
 # The full license is in the file LICENSE.txt, distributed with this software.
@@ -8,6 +8,8 @@
 #-----------------------------------------------------------------------------
 # Boilerplate
 #-----------------------------------------------------------------------------
+from __future__ import annotations # isort:skip
+
 import pytest ; pytest
 
 #-----------------------------------------------------------------------------
@@ -56,7 +58,7 @@ def test_subscribe() -> None:
 def test_destroy_calls() -> None:
     d = Document()
     s = bss.ServerSession('some-id', d, 'ioloop')
-    with mock.patch('bokeh.document.Document.delete_modules') as docdm:
+    with mock.patch('bokeh.document.modules.DocumentModuleManager.destroy') as docdm:
         with mock.patch('bokeh.document.Document.remove_on_change') as docroc:
             s.destroy()
             assert s.destroyed
